unit DatenStruktur;

interface

uses
  Graphics,
  DatenVektor;

type TRect = record //Ein Blanko-Rechteck
  Left, Top, Right, Bottom: Integer;
end;

type
  TRoadLine = Record
    x1,y1,x2,y2:single;
end;

type
  TVertice=Record   //ein Punkt IM 3D Raum
    x,y,z:single;
end;

type
  TPolygon=Record     //Werte eines Blanko Polygon (Unterordnug des Objekts)
    PolyTyp:integer;      //Type 0=Rahmen Polygon fr Kollisionscheck 9=zu zeigende Grafik
    color: TColor;    //Farbe des Polygons
    Texture: integer; //Tapetenoffset
    Draw: PiArray ; //array of integer; //Offsets der Vertices
end;

type
  TObjekt=RECORD              //Ein Objekt in der Welt (Auto, Hinderniss, Hintergrund)
    text: array [0..20] of char;
    ObjTyp:byte;                 //Type des Objekts (wird nicht verwendet)
    vert: PsArray;  //  array of TVertice;   //diverse Vertices
    PolyCou:integer;          //Anzahl Polygone im Objekt
    poly: array of TPolygon;   //Polygonzeiger
    CheckRadius: single;
end;

type
  TStatic=Record        //Statische Zuordnung eines Objekts zu einem Quadranten
    dx,dy,dz:single;    //Verschiebung Objekt im Quadranten
    umx,umy,umz:single; //Drehung des Objekts um eigene Achse
    ob:integer;         //zugewiesenes Objekt
end;

type
  TQuadrant=RECORD        //Eine Einheit in der Welt . Diese kapselt diverse statische Elemente, die auf Objekte zeigen. Diese Objekte werden schliesslich dargestellt.
    x,y,z:integer;        //Pos. des Quadranten in der Welt
    co:integer;           //Anzahl Objekte im Quadranten
    st:array of TStatic; //Zeiger auf diverse Objekte in dem Quadranten
end;

type
  TActor=Record
    x,y,z:single;	   //Position in der Welt (wo bin ich in der 10*500 x 10*500 Welt)
    qx,qy,qz:single; //Position im Quadranten (wo bin ich in der 500x500 Quadrantenmatrix)
    wx,wy,wz:integer; //Pos in Quadrantenmatrix (wo bin ich in der 10x10 Unterteilung der Welt in Quadranten)
    kx,ky,kz:single;  //Pos fr Ermittlung Winkeldifferenz bei Kollision
    umx,umy,umz:single;    //Letzte Winkel Karosserie (nicht unbedingt Fahrtrichtung) (Winkel um X,Y,Z-Achse ...)
    lx,ly,lz,lk:single;	   //Letzte Position (last x, last y ...)
    lumx,lumy,lumz:single; //Letzte Winkel (last Winkel um X ...)
    duz:single;    //Winkel Radstellung um Z = Fahrtrichtung
    dumz:single;        //Differenz Winkel zwischen Karosserie und Radeinschlag
    ob:integer;		   //Objekt Offset (Welches Objekt verwendet der Actor)
    sp:single;  	   //Speed des Actors
    kmh:single;      //Kilometer pro Stunde
    quadrant:integer; //In welchem Quadranten steckt der Actor gerade?
    OnRoad:integer;       //befindet sich der Actor auf der Strasse?
    Kontakt: array [0..19] of integer; //0...9 = Kontaktflchen
    Runde:integer; //in welcher Runde befinden sich Actor
    CheckPoint: array [0..100] of integer; //Wenn im Quadranten X Streckencheckpoint, dann Quadrantnummer belegen - CheckPoint[100] fr StartCheckPoint
    CheckPointSumme: integer;  //Addition einzelner CheckPoint-Quadranten fr Prfung, ob Runde geschafft
    lenkt:single; //Wird beim Lenken hochgezhlt
    damage:integer; //Schadensausmass 0...100
    //Physikgren
    gx,gy,gz:single; //Pos. Schwerpunkt im Fahrzeug
    v:single;       //Speed km/h
    vx:single;      //Speed km/h alter Wert
    a:single;       //Beschleunigung m/s^2
    ax:single;      //Beschleunigung m/s^2 alter Wert
    s:single;       //Zurckgelegter Weg
    m:single;       //Masse des Fahrzeugs in Kilo
    n:single;       //Drehzahl Motor 1/min^-1
    nMin:single;    //Min Drehzahl des Motors
    nMax:single;    //Max Drehzahl des Motors
    g:integer;      //eingelegter Gang
    gl:integer;     //letzter eingelegter Gang
    gd:integer;     //Richtung des Gasgebens
    r:single;       //Radius der gefahrenen Kurve
    fz:single;      //Zentralkraft
    m0:single;      //Reibungszahl Fahrbahn (0,5=trockene Fahrbahn)
    vrutsch:single; //Speed, wenn Fahrzeug rutscht
    rutscht:boolean;   //Rutscht der Wagen?
    vkipp:single;   //Speed, wenn Fahrzeug kippt
    Wkin:single;    //kinetische Enerhie Fahrtrichtung
    rdyn:single;    // dyn. Radhalbmesser [m]
    U: single;      // Umfang Reifen
    iA:single;      // konstante Achsbersetzung (Differentialgetriebe)
    iG: array [0..9] of single; //bersetzungen der Gnge 1..5 / 9=Rckwrts
    GS: array [0..9] of single; //Schlupf in den einzelnen Gngen
    Nt:single;      // Wirkungsgrad Kraftbertragung
    lr:single;      // Radstand in Meter
    lv:single;      // Schwerpunkt hinter der Vorderachse in Meter
    hs:single;      // Schwerpunkthhe ber der Fahrbahn
    bv:single;      // Spurweite vorne und hinten
    cw:single;      // Kennwert Luftwiderstand Front-Angriffsflche des Fahrzeugs
    Af:single;      // Kfz-Frontflche wo Luft angreift [m^2]
    cwp:single;     // Produkt letzten beiden Werte
    FA:single;      // Zugkraft Fahrzeug
    FX:single;      // berschusskraft
    Fw:single;      // Fahrwiderstand
    Wf:single;      // Widerstandsbeiwert des Fahrbahnbeschaffenheit (Luftreifen auf Asphalt=0.015)
    Fr:single;      // Rollwiderstand Fahrzeug
    Fg:single;      // Gewichtskraft Fahrzeug
    PM: single;     // Leistung Motor
    PRg: single;    // Radwiderstandsleistung
    PL:single;      // Luftwiderstandsleistung
    PSt:single;     // Steigungswiderstands-Leistung
    Pwi:single;     // Fahr-Gesamtwiderstand
end;

Type
  TLines=Record
    Obj:integer;		   //auf Kollision zu prfende Linie gehrt zu welchem Objekt?
    Typ:integer;       //welcher Typ hat diese Linie
    x1,y1,x2,y2:single;	   //2D-Koordinaten der Linie, die auf Kollision geprft werden soll
end;

Type
  TKollisionsLinien=Record
    LineCou:integer;
    Lines: array of TLines;
end;

implementation

end.
